Learn R Programming

AffyExpress (version 1.38.0)

AffyQA: Microarray quality control and assessment

Description

Create quality control report in an HTML file that contains a set of assessment plots, including Affymetrix recommended quality assessment, RNA quality assessment, sample quality assessment, quality diagnostic using PLM (pseudo-chip images and NUSE and RLE plots) in your current working directory.

Usage

AffyQA(parameters, raw, Output="AffyQA.html")

Arguments

parameters
a list of variables
raw
an 'AffyBatch'
Output
name of the output file

Value

This function only create an html file

Examples

Run this code
## Not run: 
# data(testData)
# AffyQA(parameters=c("group", "gender"), testData)
# ## End(Not run)

Run the code above in your browser using DataLab