Usage
AffyRegress(normal.data, cov, compare1, compare2, method, int=NULL, level=NULL, adj="none", p.value=0.05, m.value=0,
filename="result")
Arguments
normal.data
an 'ExpressionSet'
cov
a list of 1-n covariates
compare1
the first value of the main covariate. For example, suppose
that the main covariate is drug, and there are three unique values:
"drug1", "drug2", and "placebo". You would like to compare "drug1" to
"drug2". Then you would use "drug1" as compare1
compare2
the second value of the main covariate. Based on the previoius
example, if you would like to compare "drug1" vs "drug2", then you would use
"drug2" as compare2
method
Three methods are supported by this function:
"L" for using LIMMA method - compute moderated t-statistics and log-odds
of differential expression by empirical Bayes shrinkage of the standard
errors towards a common value;
"F" for using ordinary linear regression;
"P" for permuation test by resampling the phenotype
int
if int=NULL, the interaction effect is not considered;
otherwise, use two integers to indicate which covariates are
considered for interaction effect. For example,
if cov<-c("estrogen","drug","time")
and you are considering the interaction between "estrogen" and
"time", then you would write int=c(1,3)
level
you only specify this term when the design matrix contains an
interaction term. Suppose that you would like to compare "drug1" to "drug2"
only when estrogen is "present", where "present" is one of the values of the
estrogen variable. You will use "present" as level.
adj
adjustment method for multiple comparison test, including "holm",
"hochberg", "hommel", "bonferroni", "BH", "BY", "fdr", "none". The default
value is "none". Type help(p.adjust) for more detail.
p.value
p value, the default value is 0.05
m.value
fold change cut-off value, default value is 0
filename
name of the output file